@@ -1,9 +1,11 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def activate(template_id):
-    '''
+    ''' 
 
     '''
 
@@ -11,7 +13,7 @@ def activate(template_id):
 
 
 def import_from_id(template_id, ignore_not_found):
-    '''
+    ''' 
 
     '''
 
@@ -19,7 +21,7 @@ def import_from_id(template_id, ignore_not_found):
 
 
 def import_from_path(path, ignore_not_found):
-    '''
+    ''' 
 
     '''
 
@@ -27,7 +29,7 @@ def import_from_path(path, ignore_not_found):
 
 
 def reset(reload_scripts):
-    '''
+    ''' 
 
     '''
 
