@@ -2,139 +2,7 @@ import sys
 import typing
 import bpy_types
 
-
-class MehsSetNormalsFromFaces(bpy_types.Operator):
-    bl_idname = None
-    ''' '''
-
-    bl_label = None
-    ''' '''
-
-    bl_options = None
-    ''' '''
-
-    bl_rna = None
-    ''' '''
-
-    id_data = None
-    ''' '''
-
-    order = None
-    ''' '''
-
-    def as_keywords(self, ignore):
-        ''' 
-
-        '''
-        pass
-
-    def as_pointer(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_add(self):
-        ''' 
-
-        '''
-        pass
-
-    def driver_remove(self):
-        ''' 
-
-        '''
-        pass
-
-    def execute(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def get(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_hidden(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_readonly(self):
-        ''' 
-
-        '''
-        pass
-
-    def is_property_set(self):
-        ''' 
-
-        '''
-        pass
-
-    def items(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_delete(self):
-        ''' 
-
-        '''
-        pass
-
-    def keyframe_insert(self):
-        ''' 
-
-        '''
-        pass
-
-    def keys(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_from_id(self):
-        ''' 
-
-        '''
-        pass
-
-    def path_resolve(self):
-        ''' 
-
-        '''
-        pass
-
-    def poll(self, context):
-        ''' 
-
-        '''
-        pass
-
-    def property_unset(self):
-        ''' 
-
-        '''
-        pass
-
-    def type_recast(self):
-        ''' 
-
-        '''
-        pass
-
-    def values(self):
-        ''' 
-
-        '''
-        pass
+GenericType = typing.TypeVar("GenericType")
 
 
 class MeshMirrorUV(bpy_types.Operator):
@@ -150,18 +18,9 @@ class MeshMirrorUV(bpy_types.Operator):
     bl_rna = None
     ''' '''
 
-    direction = None
-    ''' '''
-
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
-    precision = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -174,6 +33,24 @@ class MeshMirrorUV(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def do_mesh_mirror_UV(self, mesh, DIR):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -204,6 +81,12 @@ class MeshMirrorUV(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -258,6 +141,18 @@ class MeshMirrorUV(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -293,9 +188,6 @@ class MeshSelectNext(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -308,6 +200,18 @@ class MeshSelectNext(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -338,6 +242,12 @@ class MeshSelectNext(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -392,6 +302,18 @@ class MeshSelectNext(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
@@ -427,9 +349,6 @@ class MeshSelectPrev(bpy_types.Operator):
     id_data = None
     ''' '''
 
-    order = None
-    ''' '''
-
     def as_keywords(self, ignore):
         ''' 
 
@@ -442,6 +361,18 @@ class MeshSelectPrev(bpy_types.Operator):
         '''
         pass
 
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -472,6 +403,12 @@ class MeshSelectPrev(bpy_types.Operator):
         '''
         pass
 
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
     def is_property_readonly(self):
         ''' 
 
@@ -526,6 +463,18 @@ class MeshSelectPrev(bpy_types.Operator):
         '''
         pass
 
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
     def property_unset(self):
         ''' 
 
