@@ -2,6 +2,8 @@ import sys
 import typing
 import bpy_types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 class PREFERENCES_OT_addon_disable(bpy_types.Operator):
     bl_idname = None
@@ -3128,7 +3130,7 @@ class PREFERENCES_OT_studiolight_install(bpy_types.Operator):
 
 
 class PREFERENCES_OT_studiolight_new(bpy_types.Operator):
-    ask_overide = None
+    ask_override = None
     ''' '''
 
     bl_idname = None
@@ -3757,19 +3759,3 @@ class PREFERENCES_OT_theme_install(bpy_types.Operator):
 
         '''
         pass
-
-
-def module_filesystem_remove(path_base, module_name):
-    ''' 
-
-    '''
-
-    pass
-
-
-def preferences_copytree(src, dst):
-    ''' 
-
-    '''
-
-    pass
