@@ -191,7 +191,187 @@ class WM_MT_splash(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_setup(self, context):
+    def driver_add(self):
+        ''' 
+
+        '''
+        pass
+
+    def driver_remove(self):
+        ''' 
+
+        '''
+        pass
+
+    def get(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_extended(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_hidden(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_overridable_library(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_readonly(self):
+        ''' 
+
+        '''
+        pass
+
+    def is_property_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def items(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_delete(self):
+        ''' 
+
+        '''
+        pass
+
+    def keyframe_insert(self):
+        ''' 
+
+        '''
+        pass
+
+    def keys(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_from_id(self):
+        ''' 
+
+        '''
+        pass
+
+    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
+                  filter_ext, filter_path, display_name, add_operator):
+        ''' 
+
+        '''
+        pass
+
+    def path_resolve(self):
+        ''' 
+
+        '''
+        pass
+
+    def pop(self):
+        ''' 
+
+        '''
+        pass
+
+    def prepend(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def property_overridable_library_set(self):
+        ''' 
+
+        '''
+        pass
+
+    def property_unset(self):
+        ''' 
+
+        '''
+        pass
+
+    def remove(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def type_recast(self):
+        ''' 
+
+        '''
+        pass
+
+    def values(self):
+        ''' 
+
+        '''
+        pass
+
+
+class WM_MT_splash_about(bpy_types.Menu, bpy_types._GenericUI):
+    bl_label = None
+    ''' '''
+
+    bl_rna = None
+    ''' '''
+
+    id_data = None
+    ''' '''
+
+    def append(self, draw_func):
+        ''' 
+
+        '''
+        pass
+
+    def as_pointer(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass(self):
+        ''' 
+
+        '''
+        pass
+
+    def bl_rna_get_subclass_py(self):
+        ''' 
+
+        '''
+        pass
+
+    def draw(self, context):
+        ''' 
+
+        '''
+        pass
+
+    def draw_collapsible(self, context, layout):
+        ''' 
+
+        '''
+        pass
+
+    def draw_preset(self, _context):
         ''' 
 
         '''
@@ -331,7 +511,7 @@ class WM_MT_splash(bpy_types.Menu, bpy_types._GenericUI):
         pass
 
 
-class WM_MT_splash_about(bpy_types.Menu, bpy_types._GenericUI):
+class WM_MT_splash_quick_setup(bpy_types.Menu, bpy_types._GenericUI):
     bl_label = None
     ''' '''
 
@@ -885,6 +1065,12 @@ class WM_OT_context_cycle_array(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1040,6 +1226,12 @@ class WM_OT_context_cycle_enum(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1195,6 +1387,12 @@ class WM_OT_context_cycle_int(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1350,6 +1548,12 @@ class WM_OT_context_menu_enum(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1666,6 +1870,12 @@ class WM_OT_context_pie_enum(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1821,6 +2031,12 @@ class WM_OT_context_scale_float(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -1976,6 +2192,12 @@ class WM_OT_context_scale_int(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2131,6 +2353,12 @@ class WM_OT_context_set_boolean(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2286,6 +2514,12 @@ class WM_OT_context_set_enum(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2441,6 +2675,12 @@ class WM_OT_context_set_float(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2751,6 +2991,12 @@ class WM_OT_context_set_int(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -2906,6 +3152,12 @@ class WM_OT_context_set_string(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -3061,6 +3313,12 @@ class WM_OT_context_set_value(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -3216,6 +3474,12 @@ class WM_OT_context_toggle(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -3371,6 +3635,12 @@ class WM_OT_context_toggle_enum(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -4143,6 +4413,12 @@ class WM_OT_operator_pie_enum(bpy_types.Operator):
         '''
         pass
 
+    def description(self, context, props):
+        ''' 
+
+        '''
+        pass
+
     def driver_add(self):
         ''' 
 
@@ -5589,12 +5865,6 @@ class WM_OT_tool_set_by_id(bpy_types.Operator):
         '''
         pass
 
-    def invoke(self, context, event):
-        ''' 
-
-        '''
-        pass
-
     def is_property_hidden(self):
         ''' 
 
@@ -5899,12 +6169,6 @@ class WM_OT_toolbar(bpy_types.Operator):
         '''
         pass
 
-    def invoke(self, context, event):
-        ''' 
-
-        '''
-        pass
-
     def is_property_hidden(self):
         ''' 
 
@@ -6638,6 +6902,22 @@ class WM_OT_url_open_preset(bpy_types.Operator):
         pass
 
 
+def context_path_decompose(data_path):
+    ''' 
+
+    '''
+
+    pass
+
+
+def context_path_to_rna_property(context, data_path):
+    ''' 
+
+    '''
+
+    pass
+
+
 def context_path_validate(context, data_path):
     ''' 
 
@@ -6646,6 +6926,14 @@ def context_path_validate(context, data_path):
     pass
 
 
+def description_from_data_path(base, data_path, prefix, value):
+    ''' 
+
+    '''
+
+    pass
+
+
 def execute_context_assign(context):
     ''' 
 
