@@ -1423,7 +1423,7 @@ class MASK_UL_layers(bpy_types.UIList, bpy_types._GenericUI):
         pass
 
 
-def draw_mask_context_menu(layout, context):
+def draw_mask_context_menu(layout, _context):
     ''' 
 
     '''
