@@ -1150,8 +1150,11 @@ class MATERIAL_PT_gpencil_fillcolor(GPMaterialButtonsPanel, bpy_types.Panel,
         pass
 
 
-class MATERIAL_PT_gpencil_options(GPMaterialButtonsPanel, bpy_types.Panel,
+class MATERIAL_PT_gpencil_preview(GPMaterialButtonsPanel, bpy_types.Panel,
                                   bpy_types._GenericUI):
+    COMPAT_ENGINES = None
+    ''' '''
+
     bl_context = None
     ''' '''
 
@@ -1336,11 +1339,8 @@ class MATERIAL_PT_gpencil_options(GPMaterialButtonsPanel, bpy_types.Panel,
         pass
 
 
-class MATERIAL_PT_gpencil_preview(GPMaterialButtonsPanel, bpy_types.Panel,
-                                  bpy_types._GenericUI):
-    COMPAT_ENGINES = None
-    ''' '''
-
+class MATERIAL_PT_gpencil_settings(GPMaterialButtonsPanel, bpy_types.Panel,
+                                   bpy_types._GenericUI):
     bl_context = None
     ''' '''
 
