@@ -410,7 +410,7 @@ class OUTLINER_MT_collection_new(bpy_types.Menu, bpy_types._GenericUI):
         '''
         pass
 
-    def draw_without_context_menu(self, context, layout):
+    def draw_without_context_menu(self, _context, layout):
         ''' 
 
         '''
