@@ -1,24 +1,25 @@
 import sys
 import typing
-from . import icons
 from . import timers
 from . import translations
 from . import handlers
+from . import icons
 
+GenericType = typing.TypeVar("GenericType")
 alembic = None
 ''' constant value bpy.app.alembic(supported=True, version=(1, 7, 16), version_string=' 1, 7, 16')
 '''
 
 autoexec_fail = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 autoexec_fail_message = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 autoexec_fail_quiet = None
-''' Undocumented, consider contributing <https://developer.blender.org/T51061> __.
+''' Undocumented, consider `contributing <https://developer.blender.org/T51061>`__.
 '''
 
 background = None
@@ -30,7 +31,7 @@ binary_path = None
 '''
 
 binary_path_python = None
-''' String, the path to the python executable (read-only). Deprecated! Use sys.executable instead.
+''' String, the path to the python executable (read-only). Deprecated! Use ``sys.executable`` instead.
 '''
 
 build_branch = None
@@ -222,7 +223,7 @@ version_cycle = None
 '''
 
 version_file = None
-''' The blend file version, compatible with bpy.data.version
+''' The blend file version, compatible with ``bpy.data.version``
 '''
 
 version_string = None
