@@ -317,11 +317,6 @@ def mirror(
         constraint_axis: typing.Union[typing.List[bool], typing.Any] = (False,
                                                                         False,
                                                                         False),
-        use_proportional_edit: typing.Union[bool, typing.Any] = False,
-        proportional_edit_falloff: typing.Optional[typing.Any] = 'SMOOTH',
-        proportional_size: typing.Optional[typing.Any] = 1.0,
-        use_proportional_connected: typing.Union[bool, typing.Any] = False,
-        use_proportional_projected: typing.Union[bool, typing.Any] = False,
         gpencil_strokes: typing.Union[bool, typing.Any] = False,
         center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
         release_confirm: typing.Union[bool, typing.Any] = False,
@@ -339,16 +334,6 @@ def mirror(
     :type orient_matrix_type: typing.Union[str, int, typing.Any]
     :param constraint_axis: Constraint Axis
     :type constraint_axis: typing.Union[typing.List[bool], typing.Any]
-    :param use_proportional_edit: Proportional Editing
-    :type use_proportional_edit: typing.Union[bool, typing.Any]
-    :param proportional_edit_falloff: Proportional Falloff, Falloff type for proportional editing mode * ``SMOOTH`` Smooth, Smooth falloff. * ``SPHERE`` Sphere, Spherical falloff. * ``ROOT`` Root, Root falloff. * ``INVERSE_SQUARE`` Inverse Square, Inverse Square falloff. * ``SHARP`` Sharp, Sharp falloff. * ``LINEAR`` Linear, Linear falloff. * ``CONSTANT`` Constant, Constant falloff. * ``RANDOM`` Random, Random falloff.
-    :type proportional_edit_falloff: typing.Optional[typing.Any]
-    :param proportional_size: Proportional Size
-    :type proportional_size: typing.Optional[typing.Any]
-    :param use_proportional_connected: Connected
-    :type use_proportional_connected: typing.Union[bool, typing.Any]
-    :param use_proportional_projected: Projected (2D)
-    :type use_proportional_projected: typing.Union[bool, typing.Any]
     :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
     :type gpencil_strokes: typing.Union[bool, typing.Any]
     :param center_override: Center Override, Force using this center value (when set)
@@ -494,7 +479,7 @@ def resize(
     :type snap_normal: typing.Optional[typing.Any]
     :param gpencil_strokes: Edit Grease Pencil, Edit selected Grease Pencil strokes
     :type gpencil_strokes: typing.Union[bool, typing.Any]
-    :param texture_space: Edit Texture Space, Edit Object data texture space
+    :param texture_space: Edit Texture Space, Edit object data texture space
     :type texture_space: typing.Union[bool, typing.Any]
     :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
     :type remove_on_cancel: typing.Union[bool, typing.Any]
@@ -988,7 +973,7 @@ def tosphere(
         center_override: typing.Optional[typing.Any] = (0.0, 0.0, 0.0),
         release_confirm: typing.Union[bool, typing.Any] = False,
         use_accurate: typing.Union[bool, typing.Any] = False):
-    ''' Move selected vertices outward in a spherical shape around mesh center
+    ''' Move selected items outward in a spherical shape around geometric center
 
     :type override_context: typing.Union[typing.Dict, 'bpy.types.Context']
     :type execution_context: typing.Union[str, int]
@@ -1254,7 +1239,7 @@ def translate(
     :type gpencil_strokes: typing.Union[bool, typing.Any]
     :param cursor_transform: Transform Cursor
     :type cursor_transform: typing.Union[bool, typing.Any]
-    :param texture_space: Edit Texture Space, Edit Object data texture space
+    :param texture_space: Edit Texture Space, Edit object data texture space
     :type texture_space: typing.Union[bool, typing.Any]
     :param remove_on_cancel: Remove on Cancel, Remove elements on cancel
     :type remove_on_cancel: typing.Union[bool, typing.Any]
@@ -1262,7 +1247,7 @@ def translate(
     :type release_confirm: typing.Union[bool, typing.Any]
     :param use_accurate: Accurate, Use accurate transformation
     :type use_accurate: typing.Union[bool, typing.Any]
-    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge & Split
+    :param use_automerge_and_split: Auto Merge & Split, Forces the use of Auto Merge and Split
     :type use_automerge_and_split: typing.Union[bool, typing.Any]
     '''
 
