@@ -1,9 +1,11 @@
 import sys
 import typing
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def complete(line, cursor, namespace):
-    '''
+    ''' 
 
     '''
 
@@ -11,7 +13,7 @@ def complete(line, cursor, namespace):
 
 
 def get_argspec(func, strip_self, doc, source):
-    '''
+    ''' 
 
     '''
 
@@ -19,7 +21,7 @@ def get_argspec(func, strip_self, doc, source):
 
 
 def get_doc(obj):
-    '''
+    ''' 
 
     '''
 
@@ -27,7 +29,7 @@ def get_doc(obj):
 
 
 def reduce_newlines(text):
-    '''
+    ''' 
 
     '''
 
@@ -35,7 +37,7 @@ def reduce_newlines(text):
 
 
 def reduce_spaces(text):
-    '''
+    ''' 
 
     '''
 
