@@ -6,7 +6,7 @@ GenericType = typing.TypeVar("GenericType")
 
 
 class ChainPredicateIterator:
-    ''' Class hierarchy: freestyle.types.Iterator > freestyle.types.ViewEdgeIterator > freestyle.types.ChainingIterator > ChainPredicateIterator A "generic" user-controlled ViewEdge iterator. This iterator is in particular built from a unary predicate and a binary predicate. First, the unary predicate is evaluated for all potential next ViewEdges in order to only keep the ones respecting a certain constraint. Then, the binary predicate is evaluated on the current ViewEdge together with each ViewEdge of the previous selection. The first ViewEdge respecting both the unary predicate and the binary predicate is kept as the next one. If none of the potential next ViewEdge respects these two predicates, None is returned.
+    ''' Class hierarchy: `freestyle.types.Iterator` > `freestyle.types.ViewEdgeIterator` > `freestyle.types.ChainingIterator` > `ChainPredicateIterator` A "generic" user-controlled ViewEdge iterator. This iterator is in particular built from a unary predicate and a binary predicate. First, the unary predicate is evaluated for all potential next ViewEdges in order to only keep the ones respecting a certain constraint. Then, the binary predicate is evaluated on the current ViewEdge together with each ViewEdge of the previous selection. The first ViewEdge respecting both the unary predicate and the binary predicate is kept as the next one. If none of the potential next ViewEdge respects these two predicates, None is returned.
     '''
 
     def __init__(self,
@@ -14,9 +14,9 @@ class ChainPredicateIterator:
                  bpred: 'freestyle.types.BinaryPredicate1D',
                  restrict_to_selection: bool = True,
                  restrict_to_unvisited: bool = True,
-                 begin: 'freestyle.types.ViewEdge' = None,
+                 begin: typing.Optional['freestyle.types.ViewEdge'] = None,
                  orientation: bool = True):
-        ''' Builds a ChainPredicateIterator from a unary predicate, a binary predicate, a starting ViewEdge and its orientation.
+        ''' __init__(brother) Builds a ChainPredicateIterator from a unary predicate, a binary predicate, a starting ViewEdge and its orientation or using the copy constructor.
 
         :param upred: The unary predicate that the next ViewEdge must satisfy.
         :type upred: 'freestyle.types.UnaryPredicate1D'
@@ -27,15 +27,9 @@ class ChainPredicateIterator:
         :param restrict_to_unvisited: Indicates whether a ViewEdge that has already been chained must be ignored ot not.
         :type restrict_to_unvisited: bool
         :param begin: The ViewEdge from where to start the iteration.
-        :type begin: 'freestyle.types.ViewEdge'
+        :type begin: typing.Optional['freestyle.types.ViewEdge']
         :param orientation: If true, we'll look for the next ViewEdge among the ViewEdges that surround the ending ViewVertex of begin. If false, we'll search over the ViewEdges surrounding the ending ViewVertex of begin.
         :type orientation: bool
-        '''
-        pass
-
-    def __init__(self, brother: 'ChainPredicateIterator'):
-        ''' Copy constructor.
-
         :param brother: A ChainPredicateIterator object.
         :type brother: 'ChainPredicateIterator'
         '''
@@ -43,27 +37,21 @@ class ChainPredicateIterator:
 
 
 class ChainSilhouetteIterator:
-    ''' Class hierarchy: freestyle.types.Iterator > freestyle.types.ViewEdgeIterator > freestyle.types.ChainingIterator > ChainSilhouetteIterator A ViewEdge Iterator used to follow ViewEdges the most naturally. For example, it will follow visible ViewEdges of same nature. As soon, as the nature or the visibility changes, the iteration stops (by setting the pointed ViewEdge to 0). In the case of an iteration over a set of ViewEdge that are both Silhouette and Crease, there will be a precedence of the silhouette over the crease criterion.
+    ''' Class hierarchy: `freestyle.types.Iterator` > `freestyle.types.ViewEdgeIterator` > `freestyle.types.ChainingIterator` > `ChainSilhouetteIterator` A ViewEdge Iterator used to follow ViewEdges the most naturally. For example, it will follow visible ViewEdges of same nature. As soon, as the nature or the visibility changes, the iteration stops (by setting the pointed ViewEdge to 0). In the case of an iteration over a set of ViewEdge that are both Silhouette and Crease, there will be a precedence of the silhouette over the crease criterion.
     '''
 
     def __init__(self,
                  restrict_to_selection: bool = True,
-                 begin: 'freestyle.types.ViewEdge' = None,
+                 begin: typing.Optional['freestyle.types.ViewEdge'] = None,
                  orientation: bool = True):
-        ''' Builds a ChainSilhouetteIterator from the first ViewEdge used for iteration and its orientation.
+        ''' __init__(brother) Builds a ChainSilhouetteIterator from the first ViewEdge used for iteration and its orientation or the copy constructor.
 
         :param restrict_to_selection: Indicates whether to force the chaining to stay within the set of selected ViewEdges or not.
         :type restrict_to_selection: bool
         :param begin: The ViewEdge from where to start the iteration.
-        :type begin: 'freestyle.types.ViewEdge'
+        :type begin: typing.Optional['freestyle.types.ViewEdge']
         :param orientation: If true, we'll look for the next ViewEdge among the ViewEdges that surround the ending ViewVertex of begin. If false, we'll search over the ViewEdges surrounding the ending ViewVertex of begin.
         :type orientation: bool
-        '''
-        pass
-
-    def __init__(self, brother: 'ChainSilhouetteIterator'):
-        ''' Copy constructor.
-
         :param brother: A ChainSilhouetteIterator object.
         :type brother: 'ChainSilhouetteIterator'
         '''
