@@ -2,11 +2,13 @@ import sys
 import typing
 import gpu.types
 
+GenericType = typing.TypeVar("GenericType")
+
 
 def batch_for_shader(shader: 'gpu.types.GPUShader',
                      type: str,
-                     content: dict,
-                     indices=None):
+                     content: typing.Dict,
+                     indices=None) -> typing.Any:
     ''' Return a batch already configured and compatible with the shader.
 
     :param shader: shader for which a compatible format will be computed.
@@ -14,7 +16,8 @@ def batch_for_shader(shader: 'gpu.types.GPUShader',
     :param type: "'POINTS', 'LINES', 'TRIS' or 'LINES_ADJ'".
     :type type: str
     :param content: Maps the name of the shader attribute with the data to fill the vertex buffer.
-    :type content: dict
+    :type content: typing.Dict
+    :rtype: typing.Any
     :return: compatible batch
     '''
 
