@@ -28,7 +28,7 @@ def draw_texture_2d(texture_id: int, position: 'mathutils.Vector',
                     width: float, height: float):
     ''' Draw a 2d texture.
 
-    :param texture_id: bpy.types.Image.bindcode ).
+    :param texture_id: `bpy.types.Image.bindcode`).
     :type texture_id: int
     :param position: Position of the lower left corner.
     :type position: 'mathutils.Vector'
